@@ -7,7 +7,7 @@
     
     A secure JavaScript SHA-1 AJAX Login.
     
-    :copyleft: 2007-2011 by the PyLucid team, see AUTHORS for more details.
+    :copyleft: 2007-2012 by the PyLucid team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details
 """
 
@@ -18,16 +18,21 @@ from django.http import HttpResponse, HttpResponseRedirect
 from django.template import RequestContext
 from django.template.loader import render_to_string
 from django.utils.translation import ugettext as _
+from django.shortcuts import render_to_response
+from django.core import urlresolvers
+from django.views.decorators.csrf import csrf_protect, csrf_exempt
 
-from pylucid_project.apps.pylucid.shortcuts import bad_request, ajax_response
+from pylucid_project.apps.pylucid.decorators import check_request
 from pylucid_project.apps.pylucid.models import LogEntry
+from pylucid_project.apps.pylucid.models.pluginpage import PluginPage
+from pylucid_project.apps.pylucid.shortcuts import bad_request, ajax_response
+from pylucid_project.pylucid_plugins.auth.forms import HoneypotForm
+from pylucid_project.pylucid_plugins.auth.models import HonypotAuth
 from pylucid_project.utils import crypt
 
 # auth own stuff
 from forms import WrongUserError, UsernameForm, ShaLoginForm
 from preference_forms import AuthPreferencesForm
-from django.views.decorators.csrf import requires_csrf_token, csrf_protect
-from pylucid_project.apps.pylucid.decorators import check_request
 
 
 APP_LABEL = "pylucid_plugin.auth"
@@ -57,11 +62,43 @@ def _get_challenge(request):
     return challenge
 
 
+@csrf_exempt
+def login_honeypot(request):
+    """
+    A login honypot.
+    """
+    faked_login_error = False
+    if request.method == 'POST':
+        form = HoneypotForm(request.POST)
+        if form.is_valid():
+            username = form.cleaned_data["username"]
+            password = form.cleaned_data["password"]            
+            HonypotAuth.objects.add(request, username, password)
+            messages.error(request, _("username/password wrong."))
+            form = HoneypotForm(initial={"username": username})
+            faked_login_error = True
+    else:
+        form = HoneypotForm()
+    context = {
+        "form": form, 
+        "form_url": request.path,
+        "page_robots": "noindex,nofollow",
+    }
+    
+    response = render_to_response("auth/login_honeypot.html", context, context_instance=RequestContext(request))
+    if faked_login_error:
+        response.status_code = 401
+    return response
+
+
 def lucidTag(request):
     """
     Create login/logout link
     example: {% lucidTag auth %}
     """
+    context = {
+        "honypot_url": "#top" # Don't use honypot
+    }
     if request.user.is_authenticated():
         template_name = "auth/logout_link.html"
         if hasattr(request.PYLUCID, "pagetree"):
@@ -74,8 +111,21 @@ def lucidTag(request):
     else:
         template_name = "auth/login_link.html"
         url = "?auth=login"
+        pref_form = AuthPreferencesForm()
+        preferences = pref_form.get_preferences()
+        use_honypot = preferences["use_honypot"]
+        if use_honypot:
+            try: # Use the first PluginPage instance
+                honypot_url = PluginPage.objects.reverse("auth", 'Auth-login_honeypot')
+            except urlresolvers.NoReverseMatch, err:
+                if settings.RUN_WITH_DEV_SERVER:
+                    print "*** Can't get 'Auth-login_honeypot' url: %s" % err
+            else:
+                context["honypot_url"] = honypot_url
 
-    return render_to_string(template_name, {"url": url}, context_instance=RequestContext(request))
+    context["url"] = url
+
+    return render_to_string(template_name, context, context_instance=RequestContext(request))
 
 
 def _wrong_login(request, debug_msg, user=None):
@@ -219,14 +269,19 @@ def _get_salt(request):
 
 @csrf_protect
 def _login_view(request):
+    """
+    For better JavaScript debugging: Enable settings.DEBUG and request the page
+    via GET with: "...?auth=login"
+    """
     if DEBUG:
         print("auth debug mode is on!")
 
     if not request.is_ajax():
         # Do nothing, if it's not a ajax request.
         if settings.DEBUG:
-            messages.error(request, "Ignore login request, because it's not AJAX.")
-        return
+            messages.info(request, "Enable non AJAX login request, because DEBUG is on.")
+        else:
+            return
 
     if request.method != 'GET':
         debug_msg = "request method %r wrong, only GET allowed" % request.method
@@ -263,7 +318,13 @@ def _login_view(request):
     request.META["CSRF_COOKIE_USED"] = True
 
     # return a string for replacing the normal cms page content
-    return ajax_response(request, 'auth/sha_form.html', context, context_instance=RequestContext(request))
+    if not request.is_ajax():
+        # Only in DEBUG mode, see above.
+        response = render_to_response('auth/sha_form_debug.html', context, context_instance=RequestContext(request))
+    else:
+        response = ajax_response(request, 'auth/sha_form.html', context, context_instance=RequestContext(request))
+        
+    return response
 
 
 def _logout_view(request):
