@@ -13,15 +13,12 @@
     PyLucid plugins should use {% extrahead %} block tag (pylucid.defaulttags.extraheadBlock)
     in plugin template for insert e.g. CSS/JS file links into html head.
 
-    :copyleft: 2009 by the PyLucid team, see AUTHORS for more details.
+    :copyleft: 2009-2011 by the PyLucid team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details
 """
 
 
-import os
-import inspect
-
-from django.conf import settings
+from django.template.loader import render_to_string
 
 
 class ContextMiddleware(object):
@@ -34,18 +31,14 @@ class ContextMiddleware(object):
         """ add all headfile links used in the current design. """
         pagetree = self.request.PYLUCID.pagetree
         design = pagetree.design
-
-        colorscheme = design.colorscheme
-        headfiles = design.headfiles.all()
-
-        for headfile in headfiles:
-            # Get a instance from pylucid_project.apps.pylucid.system.headfile.HeadfileLink():
-            headfilelink = headfile.get_headfilelink(colorscheme)
-            head_tag = headfilelink.get_head_tag()
-            self.extrahead.append(head_tag)
+        self.extrahead.append(design.get_headfile_data())
 
     def render(self):
         """ return all extra head content with all headfiles from current used design """
         self._add_pagetree_headfiles()
+
+#        for entry in self.extrahead:
+#            print "***", entry
+
         return "\n".join(self.extrahead)
 
