@@ -8,15 +8,28 @@
     Info:
         - PyLucid initial data contains english and german pages.
     
-    :copyleft: 2010-2011 by the PyLucid team, see AUTHORS for more details.
+    :copyleft: 2010-2012 by the PyLucid team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
 import os
+import sys
 
 if __name__ == "__main__":
-    # run all unittest directly
-    os.environ['DJANGO_SETTINGS_MODULE'] = "pylucid_project.settings"
+    # Run all unittest directly
+
+    tests = __file__
+#    tests = "pylucid_plugins.page_admin.tests.BulkEditorCsrfTest"
+#    tests = "pylucid_plugins.page_admin.tests.PageAdminTest.test_translate_form"
+
+    from pylucid_project.tests import run_test_directly
+    run_test_directly(tests,
+        verbosity=2,
+#        failfast=True,
+        failfast=False,
+    )
+    sys.exit()
+
 
 from django.conf import settings
 from django.test.client import Client
@@ -534,7 +547,7 @@ class ConvertMarkupTest(basetest.BaseLanguageTestCase):
         )
         self.assertResponse(response,
             must_contain=(
-                '<link rel="stylesheet" type="text/css" href="/media/PyLucid_cache/pygments.css"',
+                '<link rel="stylesheet" type="text/css" href="/static/PyLucid_cache/pygments.css"',
                 'The original markup is: <strong>tinytextile</strong>',
             ),
             must_not_contain=(
@@ -590,17 +603,3 @@ class BulkEditorCsrfTest(PageAdminTestCase):
             ),
         )
 
-
-
-if __name__ == "__main__":
-    # Run all unittest directly
-    from django.core import management
-
-    tests = __file__
-    tests = "pylucid_plugins.page_admin.tests.BulkEditorCsrfTest"
-#    tests = "pylucid_plugins.page_admin.tests.PageAdminTest.test_translate_form"
-
-    management.call_command('test', tests,
-        verbosity=2,
-        failfast=True
-    )
